@@ -5,20 +5,29 @@ start_time  <- Sys.time()
 here::i_am("inst/sbc/make_reference_rankhist.R")
 library(here)
 
-library(pkgbuild)
-## ensure that the current dev version of RBesT is loaded
-pkgbuild::compile_dll(here())
+rbest_lib_dir <- here("build", "installed")
+rbest_source_dir <- here()
+
+## ensure that the current dev version of OncoBayes2 is build and
+## loaded.
+## code to use if one wants the more conservative load_OB2_dev_install routine to be used
+setwd(here())
+system("make dev-install", ignore.stdout=TRUE, ignore.stderr=TRUE)
+setwd(here("inst", "sbc"))
 
 pkg <- c("assertthat", "rstan", "mvtnorm", "checkmate", "Formula", "abind", "dplyr", "tidyr", "here", "bayesplot")
 sapply(pkg, require, character.only=TRUE)
 
-
 library(clustermq)
 library(data.table)
 library(knitr)
 sbc_tools <- new.env()
 source(here("inst", "sbc", "sbc_tools.R"), local=sbc_tools)
-set.seed(453453)
+set.seed(45348346)
+
+sbc_tools$rbest_lib_dir <- rbest_lib_dir
+sbc_tools$rbest_source_dir <- rbest_source_dir
+sbc_tools$load_rbest_dev()
 
 scheduler <- getOption("clustermq.scheduler")
 
@@ -71,7 +80,7 @@ num_simulations <- nrow(scenarios)
 cat("Total number of jobs to dispatch:", num_simulations, "\n")
 
 RNGkind("L'Ecuyer-CMRG")
-set.seed(56969)
+set.seed(269698974)
 rng_seeds <- sbc_tools$setup_lecuyer_seeds(.Random.seed, num_simulations)
 
 sim_result <- Q_rows(scenarios, sbc_tools$run_sbc_case, const=list(base_scenarios=base_scenarios, seeds=rng_seeds), export=as.list(sbc_tools), n_jobs=n_jobs, pkgs=pkg)
@@ -121,7 +130,7 @@ git_hash <- system2("git", c("rev-parse", "HEAD"), stdout=TRUE)
 created <- Sys.time()
 created_str <- format(created, "%F %T %Z", tz="UTC")
 
-calibration <- list(raw=calibration_data,
+calibration <- list(## raw=calibration_data, ## stop storing raw results, which are not needed for SBC reports
                     data=calibration_data_binned,
                     sampler_diagnostics = sampler_diagnostics,
                     S=S,
@@ -130,6 +139,7 @@ calibration <- list(raw=calibration_data,
                     created=created)
 
 saveRDS(calibration, file="calibration.rds")
+saveRDS(calibration_data, file="calibration_data.rds")
 
 library(tools)
 md5 <- md5sum("calibration.rds")
