@@ -1,5 +1,3 @@
-context("pos1S: 1-Sample Probability of Success")
-
 ## test the analytical OC function via brute force simulation
 set.seed(12354)
 
@@ -50,19 +48,18 @@ test_pos1S <- function(prior, ia_dist, n, dec, decU) {
 }
 
 
-test_that("Normal PoS 1 sample function matches MC integration of CPO", test_pos1S(prior, ia_dist, n1, decA, decAU))
+test_that("Normal PoS 1 sample function matches MC integration of CPO", { test_pos1S(prior, ia_dist, n1, decA, decAU) })
 
 beta_prior <- mixbeta(c(1, 1, 1))
 beta_ia <- postmix(beta_prior, r=20, n=50)
-test_that("Binomial PoS 1 sample function matches MC integration of CPO", test_pos1S(beta_prior, beta_ia, n1, decA, decAU))
+test_that("Binomial PoS 1 sample function matches MC integration of CPO", { test_pos1S(beta_prior, beta_ia, n1, decA, decAU) })
 
 gamma_prior <- mixgamma(c(1, 1, 1), param="mn")
 dec_count  <- decision1S(1-alpha, 1, lower.tail=TRUE)
 dec_countU  <- decision1S(1-alpha, 1, lower.tail=FALSE)
 gamma_ia <- postmix(gamma_prior, m=0.9, n=40)
-test_that("Poisson PoS 1 sample function matches MC integration of CPO", test_pos1S(gamma_prior, gamma_ia, n1, dec_count, dec_countU))
+test_that("Poisson PoS 1 sample function matches MC integration of CPO", { test_pos1S(gamma_prior, gamma_ia, n1, dec_count, dec_countU) })
 
 prior_unit_inf <- mixnorm(c(1, 0, 1), sigma=s, param="mn")
 post_ia_unit_inf <- postmix(prior_unit_inf, m=-1, n=162)
-test_pos1S(prior_unit_inf, post_ia_unit_inf, 459-162, decA, decAU)
-test_that("Normal PoS 1 sample function matches MC integration of CPO (more extreme case)", test_pos1S(prior_unit_inf, post_ia_unit_inf, 459-162, decA, decAU))
+test_that("Normal PoS 1 sample function matches MC integration of CPO (more extreme case)", { test_pos1S(prior_unit_inf, post_ia_unit_inf, 459-162, decA, decAU) })
